==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/VirtualNodeSpecListenerTimeoutHttp2IdleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTimeoutHttp2IdleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property unit Unit of time. Valid values: `ms`, `s`.
 * @property value Number of time units. Minimum value of `0`.
 */
public data class VirtualNodeSpecListenerTimeoutHttp2IdleArgs(
    public val unit: Output<String>,
    public val `value`: Output<Int>,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTimeoutHttp2IdleArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTimeoutHttp2IdleArgs =
        com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTimeoutHttp2IdleArgs.builder()
            .unit(unit.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualNodeSpecListenerTimeoutHttp2IdleArgs].
 */
@PulumiTagMarker
public class VirtualNodeSpecListenerTimeoutHttp2IdleArgsBuilder internal constructor() {
    private var unit: Output<String>? = null

    private var `value`: Output<Int>? = null

    /**
     * @param value Unit of time. Valid values: `ms`, `s`.
     */
    @JvmName("gyepmywcbcjncdmw")
    public suspend fun unit(`value`: Output<String>) {
        this.unit = value
    }

    /**
     * @param value Number of time units. Minimum value of `0`.
     */
    @JvmName("ktxtptiegcupnfmk")
    public suspend fun `value`(`value`: Output<Int>) {
        this.`value` = value
    }

    /**
     * @param value Unit of time. Valid values: `ms`, `s`.
     */
    @JvmName("ybiifgbaerfvtpiq")
    public suspend fun unit(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.unit = mapped
    }

    /**
     * @param value Number of time units. Minimum value of `0`.
     */
    @JvmName("hkajacehbxdqkgol")
    public suspend fun `value`(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): VirtualNodeSpecListenerTimeoutHttp2IdleArgs =
        VirtualNodeSpecListenerTimeoutHttp2IdleArgs(
            unit = unit ?: throw PulumiNullFieldException("unit"),
            `value` = `value` ?: throw PulumiNullFieldException("value"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/VirtualNodeSpecListenerTimeoutHttp2IdleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTimeoutHttp2IdleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property unit Unit of time. Valid values: `ms`, `s`.
 * @property value Number of time units. Minimum value of `0`.
 */
public data class VirtualNodeSpecListenerTimeoutHttp2IdleArgs(
    public val unit: Output<String>,
    public val `value`: Output<Int>,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTimeoutHttp2IdleArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTimeoutHttp2IdleArgs =
        com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTimeoutHttp2IdleArgs.builder()
            .unit(unit.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualNodeSpecListenerTimeoutHttp2IdleArgs].
 */
@PulumiTagMarker
public class VirtualNodeSpecListenerTimeoutHttp2IdleArgsBuilder internal constructor() {
    private var unit: Output<String>? = null

    private var `value`: Output<Int>? = null

    /**
     * @param value Unit of time. Valid values: `ms`, `s`.
     */
    @JvmName("psoiqkpcosoonmig")
    public suspend fun unit(`value`: Output<String>) {
        this.unit = value
    }

    /**
     * @param value Number of time units. Minimum value of `0`.
     */
    @JvmName("hsnmcmjcfewqgfkb")
    public suspend fun `value`(`value`: Output<Int>) {
        this.`value` = value
    }

    /**
     * @param value Unit of time. Valid values: `ms`, `s`.
     */
    @JvmName("svcbibsqxjrllepy")
    public suspend fun unit(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.unit = mapped
    }

    /**
     * @param value Number of time units. Minimum value of `0`.
     */
    @JvmName("kfxleoxykepejxmg")
    public suspend fun `value`(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): VirtualNodeSpecListenerTimeoutHttp2IdleArgs =
        VirtualNodeSpecListenerTimeoutHttp2IdleArgs(
            unit = unit ?: throw PulumiNullFieldException("unit"),
            `value` = `value` ?: throw PulumiNullFieldException("value"),
        )
}
